;******************** (C) COPYRIGHT MindMotion ********************
;* File Name          : startup_MM32P0xx.s
;* Author             : AE Team
;* Version            : V1.0.0
;* Date               : 2017.3.31
;* Description        : MM32P0xx devices vector table for MDK-ARM toolchain.
;*                      This module performs:
;*                      - Set the initial SP
;*                      - Set the initial PC == Reset_Handler
;*                      - Set the vector table entries with the exceptions ISR address
;*                      - Configure the system clock
;*                      - Branches to __main in the C library (which eventually
;*                        calls main()).
;*                      After Reset the CortexM0 processor is in Thread mode,
;*                      priority is Privileged, and the Stack is set to Main.
;* <<< Use Configuration Wizard in Context Menu >>>   
; 
;*******************************************************************************
;
; Amount of memory (in bytes) allocated for Stack
; Tailor this value to your application needs
; <h> Stack Configuration
;   <o> Stack Size (in Bytes) <0x0-0xFFFFFFFF:8>
; </h>

Stack_Size      EQU     0x00000020

                AREA    STACK, NOINIT, READWRITE, ALIGN=3
Stack_Mem       SPACE   Stack_Size
__initial_sp


; <h> Heap Configuration
;   <o>  Heap Size (in Bytes) <0x0-0xFFFFFFFF:8>
; </h>

Heap_Size       EQU     0x00000020

                AREA    HEAP, NOINIT, READWRITE, ALIGN=3
__heap_base
Heap_Mem        SPACE   Heap_Size
__heap_limit

                PRESERVE8
                THUMB


; Vector Table Mapped to Address 0 at Reset
                AREA    RESET, DATA, READONLY
                EXPORT  __Vectors
                EXPORT  __Vectors_End
                EXPORT  __Vectors_Size

__Vectors       DCD     __initial_sp                   ; Top of Stack
                DCD     Reset_Handler                  ; Reset Handler
                DCD     NMI_Handler                    ; NMI Handler
                DCD     HardFault_Handler              ; Hard Fault Handler
                DCD     0                              ; Reserved
                DCD     0                              ; Reserved
                DCD     0                              ; Reserved
                DCD     0                              ; Reserved
                DCD     0                              ; Reserved
                DCD     0                              ; Reserved
                DCD     0                              ; Reserved
                DCD     SVC_Handler                    ; SVCall Handler
                DCD     0                              ; Reserved
                DCD     0                              ; Reserved
                DCD     PendSV_Handler                 ; PendSV Handler
                DCD     SysTick_Handler                ; SysTick Handler

                ; External Interrupts
                DCD     EXTI0_IRQHandler               ; EXTI Line 0
                DCD     EXTI1_IRQHandler               ; EXTI Line 1
                DCD     EXTI2_IRQHandler               ; EXTI Line 2
                DCD     EXTI3_IRQHandler               ; EXTI Line 3
                DCD     EXTI4_IRQHandler               ; EXTI Line 4
                DCD     TC0_IRQHandler                 ; TC0
                DCD     TC1_IRQHandler                 ; TC1
                DCD     ADC_IRQHandler                 ; ADC
               
                
__Vectors_End

__Vectors_Size  EQU  __Vectors_End - __Vectors

                AREA    |.text|, CODE, READONLY

; Reset handler routine
Reset_Handler    PROC
                 EXPORT  Reset_Handler                 [WEAK]
        IMPORT  __main
        ;IMPORT  SystemInit



        ;LDR     R0, =__initial_sp          ; set stack pointer 
        ;MSR     MSP, R0  

;;Check if boot space corresponds to test memory 

        ;LDR R0,=0x00000004
        ;LDR R1, [R0]
        ;LSRS R1, R1, #24
        ;LDR R2,=0x1F
        ;CMP R1, R2
        
        ;BNE ApplicationStart  
     
;; SYSCFG clock enable    
     
        ;LDR R0,=0x40021018 
        ;LDR R1,=0x00000001
        ;STR R1, [R0]
        
;; Set CFGR1 register with flash memory remap at address 0

        ;LDR R0,=0x40010000 
        ;LDR R1,=0x00000000
        ;STR R1, [R0]
ApplicationStart         
                 ;LDR     R0, =SystemInit
                 ;BLX     R0
                 LDR     R0, =__main
                 BX      R0
                 ENDP

; Dummy Exception Handlers (infinite loops which can be modified)

NMI_Handler     PROC
                EXPORT  NMI_Handler                    [WEAK]
                B       .
                ENDP
HardFault_Handler\
                PROC
                EXPORT  HardFault_Handler              [WEAK]
                B       .
                ENDP
SVC_Handler     PROC
                EXPORT  SVC_Handler                    [WEAK]
                B       .
                ENDP
PendSV_Handler  PROC
                EXPORT  PendSV_Handler                 [WEAK]
                B       .
                ENDP
SysTick_Handler PROC
                EXPORT  SysTick_Handler                [WEAK]
                B       .
                ENDP

Default_Handler PROC

                EXPORT  EXTI0_IRQHandler                [WEAK]
                EXPORT  EXTI1_IRQHandler                [WEAK]
                EXPORT  EXTI2_IRQHandler                [WEAK]
                EXPORT  EXTI3_IRQHandler                [WEAK]
                EXPORT  EXTI4_IRQHandler                [WEAK]
                EXPORT  TC0_IRQHandler                  [WEAK]
                EXPORT  TC1_IRQHandler                  [WEAK]
                EXPORT  ADC_IRQHandler                  [WEAK]
                


EXTI0_IRQHandler
EXTI1_IRQHandler
EXTI2_IRQHandler
EXTI3_IRQHandler
EXTI4_IRQHandler
TC0_IRQHandler
TC1_IRQHandler
ADC_IRQHandler

                B       .

                ENDP

                ALIGN

;*******************************************************************************
; User Stack and Heap initialization
;*******************************************************************************
                 IF      :DEF:__MICROLIB
                
                 EXPORT  __initial_sp
                 EXPORT  __heap_base
                 EXPORT  __heap_limit
                
                 ELSE
                
                 IMPORT  __use_two_region_memory
                 EXPORT  __user_initial_stackheap
                 
__user_initial_stackheap

                 LDR     R0, =  Heap_Mem
                 LDR     R1, =(Stack_Mem + Stack_Size)
                 LDR     R2, = (Heap_Mem +  Heap_Size)
                 LDR     R3, = Stack_Mem
                 BX      LR

                 ALIGN

                 ENDIF

                 END

;************************ (C) COPYRIGHT MindMotion *****END OF FILE*****
